@@ -21,15 +21,15 @@
 #ifndef _SFCGAL_VERSION_H_
 #define _SFCGAL_VERSION_H_
 
-#include <SFCGAL/export.h>
+#include "SFCGAL/export.h"
 
 #define SFCGAL_VERSION_MAJOR 1
 #define SFCGAL_VERSION_MINOR 5
-#define SFCGAL_VERSION_PATCH 1
+#define SFCGAL_VERSION_PATCH 2
 
-#define SFCGAL_VERSION "1.5.1"
+#define SFCGAL_VERSION "1.5.2"
 
-#define SFCGAL_FULL_VERSION "SFCGAL 1.5.1, CGAL 5.6, BOOST 1.84.0"
+#define SFCGAL_FULL_VERSION "SFCGAL 1.5.2, CGAL 5.6.1, BOOST 1.85.0"
 
 namespace SFCGAL {
     SFCGAL_API const char* Version();
